@@ -14,7 +14,7 @@
   packageStartupMessage("**         T4cluster || Tools for Cluster Analysis          ")
   packageStartupMessage("**")
   packageStartupMessage("** Version    : ",this.version,"       (",this.year,")",sep="")
-  packageStartupMessage("** Maintainer : Kisung You  (kisungyou@outlook.com)")
+  packageStartupMessage("** Maintainer : Kisung You  (kisung.you@outlook.com)")
   packageStartupMessage("** Website    : https://kisungyou.com/T4cluster/")
   packageStartupMessage("**")
   packageStartupMessage("** Please share any bugs or suggestions to the maintainer.")
